Module model

Module model 

Multi-head EML model with training via coordinate descent.

EmlModel is a generic, domain-agnostic learned function that maps N input features to M output heads. It uses the EML operator tree internally and trains via random restart + coordinate descent.

Structs

EmlModel
Multi-head EML model for O(1) function approximation.